@@ -4,4 +4,4 @@ import foran.cli as cli
 
 
 def test_cli():
-    assert cli.main(['argument']) == 0
+    assert cli.main(['foran-eller-bagved.txt']) == 0
